==> php54-owncloud-8.0.4.tgz: share/owncloud/lib/l10n/ro.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nu se poate scrie în folderul \"config\"!",
    "See %s" : "Vezi %s",
    "PHP %s or higher is required." : "Versiunea PHP %s sau mai mare este necesară.",
    "Help" : "Ajutor",
    "Personal" : "Personal",
    "Settings" : "Setări",
    "Users" : "Utilizatori",
    "Admin" : "Admin",
    "Recommended" : "Recomandat",
    "No app name specified" : "Niciun nume de aplicație specificat",
    "Unknown filetype" : "Tip fișier necunoscut",
    "Invalid image" : "Imagine invalidă",
    "today" : "astăzi",
    "yesterday" : "ieri",
    "_%n day ago_::_%n days ago_" : ["","",""],
    "last month" : "ultima lună",
    "_%n month ago_::_%n months ago_" : ["%n lună în urmă","%n luni în urmă","%n luni în urmă"],
    "last year" : "ultimul an",
    "_%n year ago_::_%n years ago_" : ["","",""],
    "_%n hour ago_::_%n hours ago_" : ["","","acum %n ore"],
    "_%n minute ago_::_%n minutes ago_" : ["","","acum %n minute"],
    "seconds ago" : "secunde în urmă",
    "web services under your control" : "servicii web controlate de tine",
    "Application is not enabled" : "Aplicația nu este activată",
    "Authentication error" : "Eroare la autentificare",
    "Token expired. Please reload page." : "Token expirat. Te rugăm să reîncarci pagina.",
    "Unknown user" : "Utilizator necunoscut",
    "%s enter the database name." : "%s introduceți numele bazei de date",
    "MS SQL username and/or password not valid: %s" : "Nume utilizator și/sau parolă MS SQL greșită: %s",
    "MySQL/MariaDB username and/or password not valid" : "Nume utilizator și/sau parolă MySQL/MariaDB greșită",
    "DB Error: \"%s\"" : "Eroare Bază de Date: \"%s\"",
    "MySQL/MariaDB user '%s'@'localhost' exists already." : "Utilizatorul MySQL/MariaDB '%s'@'localhost' deja există.",
    "Drop this user from MySQL/MariaDB" : "Șterge acest utilizator din MySQL/MariaDB",
    "MySQL/MariaDB user '%s'@'%%' already exists" : "Utilizatorul MySQL/MariaDB '%s'@'%%' deja există.",
    "Drop this user from MySQL/MariaDB." : "Șterge acest utilizator din MySQL/MariaDB.",
    "Oracle connection could not be established" : "Conexiunea Oracle nu a putut fi stabilită",
    "PostgreSQL username and/or password not valid" : "Nume utilizator și/sau parolă PostgreSQL greșită",
    "Set an admin username." : "Setează un nume de administrator.",
    "Set an admin password." : "Setează o parolă de administrator.",
    "%s shared »%s« with you" : "%s Partajat »%s« cu tine de",
    "You are not allowed to share %s" : "Nu există permisiunea de partajare %s",
    "Share type %s is not valid for %s" : "Tipul partajării %s nu este valid pentru %s",
    "Could not find category \"%s\"" : "Cloud nu a gasit categoria \"%s\"",
    "A valid username must be provided" : "Trebuie să furnizaţi un nume de utilizator valid",
    "A valid password must be provided" : "Trebuie să furnizaţi o parolă validă",
    "The username is already being used" : "Numele de utilizator este deja folosit",
    "Cannot write into \"config\" directory" : "Nu se poate scrie în folderul \"config\"",
    "Cannot write into \"apps\" directory" : "Nu se poate scrie în folderul \"apps\"",
    "PHP module %s not installed." : "Modulul PHP %s nu este instalat.",
    "PHP modules have been installed, but they are still listed as missing?" : "Modulele PHP au fost instalate, dar apar ca lipsind?",
    "PostgreSQL >= 9 required" : "Este necesară versiunea 9 sau mai mare a PostgreSQL",
    "Please upgrade your database version" : "Actualizați baza de date la o versiune mai nouă",
    "Error occurred while checking PostgreSQL version" : "A apărut o eroare la verificarea versiunii PostgreSQL"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> php54-owncloud-8.1.0.tgz: share/owncloud/lib/l10n/ro.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Nu se poate scrie în folderul \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Aceasta se poate repara de obicei prin permiterea accesului de scriere la dosarul de configurarea a webserverului",
    "See %s" : "Vezi %s",
    "PHP %s or higher is required." : "Versiunea PHP %s sau mai mare este necesară.",
    "PHP with a version lower than %s is required." : "Este necesară o versiune PHP mai mică decât %s",
    "Following platforms are supported: %s" : "Sunt suportate următoarele platforme: %s",
    "ownCloud %s or higher is required." : "ownCloud %s sau mai mare este necesar.",
    "ownCloud with a version lower than %s is required." : "ownCloud cu o versiune mai mică decât %s este necesară.",
    "Help" : "Ajutor",
    "Personal" : "Personal",
    "Users" : "Utilizatori",
    "Admin" : "Admin",
    "Recommended" : "Recomandat",
    "No app name specified" : "Niciun nume de aplicație specificat",
    "Unknown filetype" : "Tip fișier necunoscut",
    "Invalid image" : "Imagine invalidă",
    "today" : "astăzi",
    "yesterday" : "ieri",
    "last month" : "ultima lună",
    "_%n month ago_::_%n months ago_" : ["%n lună în urmă","%n luni în urmă","%n luni în urmă"],
    "last year" : "ultimul an",
    "_%n year ago_::_%n years ago_" : ["%n an în urmă","%n ani în urmâ","%n ani în urmâ"],
    "seconds ago" : "secunde în urmă",
    "web services under your control" : "servicii web controlate de tine",
    "Empty filename is not allowed" : "Nu este permis fișier fără nume",
    "File name is too long" : "Numele fișierului este prea lung",
    "Application is not enabled" : "Aplicația nu este activată",
    "Authentication error" : "Eroare la autentificare",
    "Token expired. Please reload page." : "Token expirat. Te rugăm să reîncarci pagina.",
    "Unknown user" : "Utilizator necunoscut",
    "%s enter the database name." : "%s introduceți numele bazei de date",
    "MS SQL username and/or password not valid: %s" : "Nume utilizator și/sau parolă MS SQL greșită: %s",
    "MySQL/MariaDB username and/or password not valid" : "Nume utilizator și/sau parolă MySQL/MariaDB greșită",
    "DB Error: \"%s\"" : "Eroare Bază de Date: \"%s\"",
    "MySQL/MariaDB user '%s'@'localhost' exists already." : "Utilizatorul MySQL/MariaDB '%s'@'localhost' deja există.",
    "Drop this user from MySQL/MariaDB" : "Șterge acest utilizator din MySQL/MariaDB",
    "MySQL/MariaDB user '%s'@'%%' already exists" : "Utilizatorul MySQL/MariaDB '%s'@'%%' deja există.",
    "Drop this user from MySQL/MariaDB." : "Șterge acest utilizator din MySQL/MariaDB.",
    "Oracle connection could not be established" : "Conexiunea Oracle nu a putut fi stabilită",
    "PostgreSQL username and/or password not valid" : "Nume utilizator și/sau parolă PostgreSQL greșită",
    "Set an admin username." : "Setează un nume de administrator.",
    "Set an admin password." : "Setează o parolă de administrator.",
    "%s shared »%s« with you" : "%s Partajat »%s« cu tine de",
    "You are not allowed to share %s" : "Nu există permisiunea de partajare %s",
    "Share type %s is not valid for %s" : "Tipul partajării %s nu este valid pentru %s",
    "Could not find category \"%s\"" : "Cloud nu a gasit categoria \"%s\"",
    "A valid username must be provided" : "Trebuie să furnizaţi un nume de utilizator valid",
    "A valid password must be provided" : "Trebuie să furnizaţi o parolă validă",
    "The username is already being used" : "Numele de utilizator este deja folosit",
    "Cannot write into \"config\" directory" : "Nu se poate scrie în folderul \"config\"",
    "Cannot write into \"apps\" directory" : "Nu se poate scrie în folderul \"apps\"",
    "PHP module %s not installed." : "Modulul PHP %s nu este instalat.",
    "PHP modules have been installed, but they are still listed as missing?" : "Modulele PHP au fost instalate, dar apar ca lipsind?",
    "PostgreSQL >= 9 required" : "Este necesară versiunea 9 sau mai mare a PostgreSQL",
    "Please upgrade your database version" : "Actualizați baza de date la o versiune mai nouă",
    "Error occurred while checking PostgreSQL version" : "A apărut o eroare la verificarea versiunii PostgreSQL"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
